pub enum EventInfo {
Connected(ConnectedInfo),
Disconnected(DisconnectedInfo),
}Available on crate feature
wifi only.Expand description
Either the ConnectedInfo or DisconnectedInfo.
Variants
Connected(ConnectedInfo)
Information about a station connected to the access point.
Disconnected(DisconnectedInfo)
Information about a station disconnected from the access point.